import { ComponentOptionsMixin } from 'vue';
import { DefineComponent } from 'vue';
import { ExtractPropTypes } from 'vue';
import { PropType } from 'vue';
import { PublicProps } from 'vue';

declare type __VLS_NonUndefinedable<T> = T extends undefined ? never : T;

declare type __VLS_NonUndefinedable_2<T> = T extends undefined ? never : T;

declare type __VLS_Prettify<T> = {
    [K in keyof T]: T[K];
} & {};

declare type __VLS_Prettify_2<T> = {
    [K in keyof T]: T[K];
} & {};

declare type __VLS_TypePropsToRuntimeProps<T> = {
    [K in keyof T]-?: {} extends Pick<T, K> ? {
        type: PropType<__VLS_NonUndefinedable<T[K]>>;
    } : {
        type: PropType<T[K]>;
        required: true;
    };
};

declare type __VLS_TypePropsToRuntimeProps_2<T> = {
    [K in keyof T]-?: {} extends Pick<T, K> ? {
        type: PropType<__VLS_NonUndefinedable_2<T[K]>>;
    } : {
        type: PropType<T[K]>;
        required: true;
    };
};

declare type __VLS_WithDefaults<P, D> = {
    [K in keyof Pick<P, keyof P>]: K extends keyof D ? __VLS_Prettify<P[K] & {
        default: D[K];
    }> : P[K];
};

declare type __VLS_WithDefaults_2<P, D> = {
    [K in keyof Pick<P, keyof P>]: K extends keyof D ? __VLS_Prettify_2<P[K] & {
        default: D[K];
    }> : P[K];
};

declare type __VLS_WithTemplateSlots<T, S> = T & {
    new (): {
        $slots: S;
    };
};

export declare const WindowControls: DefineComponent<__VLS_WithDefaults<__VLS_TypePropsToRuntimeProps<WindowControlsProps>, {
    justify: boolean;
    hide: boolean;
    hideMethod: string;
    className: string;
}>, {}, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<ExtractPropTypes<__VLS_WithDefaults<__VLS_TypePropsToRuntimeProps<WindowControlsProps>, {
    justify: boolean;
    hide: boolean;
    hideMethod: string;
    className: string;
}>>>, {
    hide: boolean;
    hideMethod: "display" | "visibility";
    justify: boolean;
    className: string;
}, {}>;

/**
 * Interface for window controls.
 * If the `platform` property is not specified, the library will automatically detect
 * the operating system the app is running on and display the appropriate elements.
 */
export declare interface WindowControlsProps {
    /**
     * Specifies which platform's window controls to display.
     * It can be one of "windows", "macos", or "gnome".
     * If the `platform` property is not specified, the library will automatically detect
     * the operating system the app is running on and display the appropriate elements.
     */
    platform?: "windows" | "macos" | "gnome";
    /**
     * Indicates whether the window controls should be shown or hidden.
     * @default false
     */
    hide?: boolean;
    /**
     * - "display": "display: none;" making them completely invisible and not taking up any space.
     * - "visibility": "visibility: hidden;" making them invisible but still occupying the same space.
     * @default "display"
     */
    hideMethod?: "display" | "visibility";
    /**
     * Justify/Snap WindowControls
     *
     * @default false, (if not defined in WindowTitlebar automatically assigned)
     */
    justify?: boolean;
    /**
     * Specifies the Linux desktop environment for which the window controls are intended.
     * This property is applicable only when the platform is set to "linux".
     * @default "gnome"
     */
    /**
     * Indicates whether to prevent the right-click context menu.
     * When set to true, it will prevent the default right-click behavior.
     * (only in production, default false)
     */
    /** `data-tauri-drag-region` */
    /**
     * to add custom class to window controls
     */
    className?: string;
}

export declare const WindowTitlebar: __VLS_WithTemplateSlots<DefineComponent<__VLS_WithDefaults_2<__VLS_TypePropsToRuntimeProps_2<WindowTitlebarProps>, {
    controlsOrder: string;
}>, {}, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<ExtractPropTypes<__VLS_WithDefaults_2<__VLS_TypePropsToRuntimeProps_2<WindowTitlebarProps>, {
    controlsOrder: string;
}>>>, {
    controlsOrder: "right" | "left" | "platform" | "system";
}, {}>, {
    default?(_: {}): any;
}>;

/**
 * Interface for titlebar
 */
export declare interface WindowTitlebarProps {
    /**
     * The `controlsOrder` property is an optional property used in the `WindowControls` interface.
     * It allows you to specify the order in which the window controls should be rendered relative to the children.
     * (default: system)
     *
     * When `controlsOrder` is not specified or set to `system`, the default behavior will be as follows:
     * - For platforms other than macOS, the controls will be on the right side of the children.
     * - For macOS, the controls will be on the left side of the children (similar to "left" option).
     *
     * Possible values for `controlsOrder`:
     * - "right": The window controls will be rendered to the right of the children.
     * - "left": The window controls will be rendered to the left of the children. This order applies only when the platform is macOS (macOS window controls are usually located on the left side of the title bar).
     * - "platform": for OS-based positioning specified in `windowControlsProps`
     * @default "system"
     */
    controlsOrder?: "right" | "left" | "platform" | "system";
    /**
     * `WindowControls` props
     */
    windowControlsProps?: WindowControlsProps;
}

export { }
